==> nextcloud-29.0.9.tgz: nextcloud/apps/photos/l10n/de_DE.js <==
OC.L10N.register(
    "photos",
    {
    "Public link" : "Öffentlicher Link",
    "Photos" : "Fotos",
    "On This Day" : "An diesem Tag",
    "Your memories under your control" : "Ihre Erinnerungen unter Ihrer Kontrolle",
    "All media" : "Alle Medien",
    "Videos" : "Videos",
    "Albums" : "Alben",
    "Collaborative albums" : "Kollaborative Alben",
    "People" : "Personen",
    "Folders" : "Ordner",
    "Favorites" : "Favoriten",
    "On this day" : "An diesem Tag",
    "Shared with you" : "Mit Ihnen geteilt",
    "Tags" : "Schlagworte",
    "Places" : "Orte",
    "Map" : "Karte",
    "Photos settings" : "Fotos-Einstellungen",
    "Mark selection as favorite" : "Auswahl als Favoriten markieren",
    "Add selection to favorites" : "Auswahl zu Favoriten hinzufügen",
    "Remove selection from favorites" : "Auswahl aus den Favoriten entfernen",
    "Name of the album" : "Name des Albums",
    "Location of the album" : "Ort des Albums",
    "Back" : "Zurück",
    "Add collaborators" : "Mitarbeitende hinzufügen",
    "Save" : "Speichern",
    "Create album" : "Erstelle Album",
    "Add to Album" : "Zum Album hinzufügen",
    "Add selection to album {albumName}" : "Auswahl zum Album {albumName} hinzufügen",
    "Shared by" : "Geteilt von",
    "Create a new album." : "Ein neues Album erstellen.",
    "Create new album" : "Neues Album erstellen",
    "New album" : "Neues Album",
    "_%n item_::_%n photos and videos_" : ["%n Stück","%n Fotos und Videos"],
    "Add people or groups who can edit your album" : "Personen oder Gruppen hinzufügen, die Ihr Album bearbeiten können",
    "Search people or groups" : "Suchen nach Personen oder Gruppen",
    "No recommendations. Start typing." : "Keine Empfehlungen. Beginnen Sie mit der Eingabe.",
    "Group" : "Gruppe",
    "Remove {collaboratorLabel} from the collaborators list" : "{collaboratorLabel} aus der Liste der Mitarbeitenden löschen",
    "Copy the public link" : "Den öffentlichen Link kopieren",
    "Public link copied!" : "Öffentlicher Link kopiert!",
    "Copy public link" : "Öffentlichen Link kopieren",
    "Delete the public link" : "Den öffentlichen Link löschen",
    "Create public link share" : "Öffentlichen Link zum Teilen erstellen",
    "Share via public link" : "Als öffentlichen Link teilen",
    "Failed to fetch collaborators list." : "Liste der Mitbearbeitenden konnte nicht abgerufen werden.",
    "Failed to update album." : "Album konnte nicht aktualisiert werden.",
    "This collection does not exist" : "Diese Sammlung existiert nicht",
    "An error occurred" : "Es ist ein Fehler aufgetreten",
    "No picture for this day" : "Kein Bild für diesen Tag",
    "Picture taken on this day will show up here." : "Ein Bild, das an diesem Tag aufgenommen wurde, wird hier angezeigt.",
    "More photos from this day" : "Weitere Bilder von diesem Tag",
    "_%n unassigned photo_::_%n unassigned photos_" : ["%n nicht zugewiesenes Foto","%n nicht zugewiesene Fotos"],
    "Favorite" : "Favorisieren",
    "Select image {imageName}" : "Bild {imageName} auswählen",
    "Favorite image, open the full size \"{name}\" image" : "Favorisiertes Bild, öffne das Bild \"{name}\" in Originalgröße",
    "Open the full size \"{name}\" image" : "Bild \"{name}\" in Originalgröße öffnen",
    "Open the \"{name}\" folder" : "Ordner \"{name}\" öffnen",
    "Go back" : "Zurückgehen",
    "Back to {folder}" : "Zurück zu {folder}",
    "Share this folder" : "Diesen Ordner teilen",
    "Dates" : "Daten",
    "Jump to specific date in list" : "Zu einem bestimmten Datum in der Liste springen",
    "Jump to {date}" : "Zu {date} springen",
    "Add to {destination}" : "Hinzufügen zu {destination}",
    "The destination folder is owned by {owner}" : "Der Zielordner gehört {owner}",
    "There are no photos or videos yet!" : "Es gibt noch keine Fotos oder Videos!",
    "_{years} year ago_::_{years} years ago_" : ["Vor {years} Jahr","Vor {years} Jahren"],
    "Enable squared photos view" : "Quadratische Fotoansicht aktivieren",
    "Delete source directory" : "Quellverzeichnis löschen",
    "All folders" : "Alle Ordner",
    "Add a Photos source for the timelines" : "In Fotos eine Quelle für die Zeitleisten hinzufügen",
    "Add folder" : "Ordner hinzufügen",
    "Select a source folder for your media" : "Quellordner für Ihre Medien wählen",
    "Home" : "Startseite",
    "Choose default Photos upload and Albums location" : "Den Standardspeicherort für das Hochladen von Fotos und Alben wählen",
    "Choose a different folder" : "Anderen Ordner wählen",
    "Select the default upload location for your media" : "Standardspeicherort für Ihre hochgeladenen Medien auswählen",
    "View" : "Ansicht",
    "Media folders" : "Medienordner",
    "Choose the folders from where photos and videos are shown." : "Ordner wählen, aus dem Fotos und Videos angezeigt werden.",
    "Upload folder" : "Hochladen-Ordner",
    "Choose the folder where photos and albums are uploaded to." : "Ordner wählen, in den Fotos und Videos hochgeladen werden.",
    "_%n photo_::_%n photos_" : ["%n Foto","%n Fotos"],
    "Unselect all" : "Auswahl aufheben",
    "Manage collaborators for this album" : "Mitbearbeitende für dieses Album verwalten",
    "Open actions menu" : "Aktionsmenü öffnen",
    "Edit album details" : "Albumdetails bearbeiten",
    "Download all files in album" : "Alle Dateien im Album herunterladen",
    "Delete album" : "Album löschen",
    "Download selected files" : "Ausgewählte Dateien herunterladen",
    "Remove selection from album" : "Auswahl aus Album entfernen",
    "This album does not have any photos or videos yet!" : "Dieses Album enthält noch keine Fotos oder Videos!",
    "Add photos to this album" : "Fotos zu diesem Album hinzufügen",
    "Add photos to {albumName}" : "Fotos hinzufügen zu {albumName}",
    "Manage collaborators" : "Mitarbeitende verwalten",
    "Save collaborators for this album." : "Mitbearbeitende für dieses Album speichern.",
    "Cover photo for album {albumName}" : "Titelbild für Album {albumName}",
    "There is no album yet!" : "Es gibt noch kein Album!",
    "This person could not be found" : "Diese Person konnte nicht gefunden werden",
    "Rename person" : "Person umbenennen",
    "Merge with different person" : "Mit einer anderen Person zusammenführen",
    "Download selected photos" : "Ausgewählte Fotos herunterladen",
    "Remove from favorites" : "Von Favoriten entfernen",
    "Remove person" : "Person entfernen",
    "Name of this person" : "Name dieser Person",
    "Save." : "Speichern.",
    "Merge person" : "Person zusammenführen",
    "Move to different person" : "Zu einer anderen Person umziehen",
    "_Move photo to a different person_::_Move photos to a different person_" : ["Foto an eine andere Person verschieben","Fotos an eine andere Person verschieben"],
    "_Remove photo from person_::_Remove photos from person_" : ["Foto von Person entfernen","Fotos von Person entfernen"],
    "This might take some time depending on the size of your photo library." : "Dies kann je nach Größe Ihrer Fotobibliothek einige Zeit dauern.",
    "Recognized people will show up here" : "Erkannte Menschen werden hier angezeigt werden",
    "This folder does not exist" : "Dieser Ordner existiert nicht",
    "Loading folders …" : "Ordner werden geladen...",
    "No photos in here" : "Keine Fotos vorhanden",
    "Taken on {date} at {time}" : "Aufgenommen am {date} um {time}",
    "This place does not have any photos or videos yet!" : "Dieser Ort enthält noch keine Fotos oder Videos!",
    "Add photos to this place" : "Fotos zu diesem Ort hinzufügen",
    "Cover photo for place {placeName}" : "Titelbild für Ort {placeName}",
    "There is no place yet!" : "Es gibt noch keinen Ort",
    "Cover photo for shared album {albumName}." : "Titelbild für das geteilte Album {albumName}.",
    "Back to tags overview" : "Zurück zur Schlagwortübersicht",
    "No photos with this tag yet" : "Noch keine Fotos mit diesem Schlagwort",
    "No tags yet" : "Noch keine Schlagworte vorhanden",
    "Photos with tags will show up here" : "Fotos mit Schlagworten werden hier angezeigt",
    "Popular tags" : "Beliebte Schlagworte",
    "All tags" : "Alle Schlagworte",
    "One of the source folders does not exists" : "Einer der Quellordner existiert nicht",
    "Add" : "Hinzufügen",
    "Add to album" : "Zum Album hinzufügen",
    "Delete selection" : "Auswahl löschen",
    "No photos or videos in here" : "Hier gibt es keine Fotos oder Videos",
    "Unassigned faces" : "Nicht zugewiesene Gesichter",
    "_%n photos_::_%n photos_" : ["%n Foto","%n Fotos"],
    "Failed to fetch collection." : "Sammlung konnte nicht abgerufen werden.",
    "Failed to fetch collections list." : "Sammlungsliste konnte nicht geladen werden.",
    "Failed to fetch faces list." : "Gesichter-Liste konnte nicht geladen werden.",
    "All your media" : "Alle Ihre Medien",
    "Album {title}" : "Album {title}",
    "Shared Albums" : "Geteilte Alben",
    "Shared album {title}" : "Geteiltes Album {title}",
    "Public album {title}" : "Öffentliches Album {title}",
    "Tagged photos" : "Fotos mit Schlagworten",
    "Tagged photo {title}" : "Fotos mit Schlagworten",
    "{title}'s face" : "{title}s Gesicht",
    "{startDate} to {endDate}" : "{startDate} bis {endDate}",
    "Details" : "Details",
    "Failed to rename {oldName} to {faceName}." : "{oldName} konnte nicht in {faceName} umbenannt werden.",
    "Failed to delete {faceName}." : "{faceName} konnte nicht gelöscht werden.",
    "Failed to delete {fileId}." : "{fileId} konnte nicht gelöscht werden.",
    "Failed to delete {fileName}." : "{fileName} konnte nicht gelöscht werden.",
    "Failed to set favorite state for {fileId}." : "Fehler beim Festlegen des Favoritenstatus für {fileId}.",
    "Failed to set favorite state for {fileName}." : "Fehler beim Festlegen des Favoritenstatus für {fileName}.",
    "Could not load photos folder" : "Fotos-Ordner konnte nicht geladen werden",
    "Default Photos upload and Albums location" : "Standardspeicherort für das Hochladen von Fotos und Alben",
    "Select the default location for your media" : "Standardspeicherort für Ihre Medien auswählen",
    "Invalid location selected" : "Ungültigen Speicherort ausgewählt",
    "Photos directory" : "Fotoverzeichnis"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-29.0.12.tgz: nextcloud/apps/photos/l10n/de_DE.js <==
OC.L10N.register(
    "photos",
    {
    "Public link" : "Öffentlicher Link",
    "Photos" : "Fotos",
    "On This Day" : "An diesem Tag",
    "Your memories under your control" : "Ihre Erinnerungen unter Ihrer Kontrolle",
    "All media" : "Alle Medien",
    "Videos" : "Videos",
    "Albums" : "Alben",
    "Collaborative albums" : "Kollaborative Alben",
    "People" : "Personen",
    "Folders" : "Ordner",
    "Favorites" : "Favoriten",
    "On this day" : "An diesem Tag",
    "Shared with you" : "Mit Ihnen geteilt",
    "Tags" : "Schlagworte",
    "Places" : "Orte",
    "Map" : "Karte",
    "Photos settings" : "Fotos-Einstellungen",
    "Mark selection as favorite" : "Auswahl als Favoriten markieren",
    "Add selection to favorites" : "Auswahl zu Favoriten hinzufügen",
    "Remove selection from favorites" : "Auswahl aus den Favoriten entfernen",
    "Name of the album" : "Name des Albums",
    "Location of the album" : "Ort des Albums",
    "Back" : "Zurück",
    "Add collaborators" : "Mitarbeitende hinzufügen",
    "Save" : "Speichern",
    "Create album" : "Erstelle Album",
    "Add to Album" : "Zum Album hinzufügen",
    "Add selection to album {albumName}" : "Auswahl zum Album {albumName} hinzufügen",
    "Shared by" : "Geteilt von",
    "Create a new album." : "Ein neues Album erstellen.",
    "Create new album" : "Neues Album erstellen",
    "New album" : "Neues Album",
    "_%n item_::_%n photos and videos_" : ["%n Stück","%n Fotos und Videos"],
    "Add people or groups who can edit your album" : "Personen oder Gruppen hinzufügen, die Ihr Album bearbeiten können",
    "Search people or groups" : "Suchen nach Personen oder Gruppen",
    "No recommendations. Start typing." : "Keine Empfehlungen. Beginnen Sie mit der Eingabe.",
    "Group" : "Gruppe",
    "Remove {collaboratorLabel} from the collaborators list" : "{collaboratorLabel} aus der Liste der Mitarbeitenden löschen",
    "Copy the public link" : "Den öffentlichen Link kopieren",
    "Public link copied!" : "Öffentlicher Link kopiert!",
    "Copy public link" : "Öffentlichen Link kopieren",
    "Delete the public link" : "Den öffentlichen Link löschen",
    "Create public link share" : "Öffentlichen Link zum Teilen erstellen",
    "Share via public link" : "Als öffentlichen Link teilen",
    "Failed to fetch collaborators list." : "Liste der Mitbearbeitenden konnte nicht abgerufen werden.",
    "Failed to update album." : "Album konnte nicht aktualisiert werden.",
    "This collection does not exist" : "Diese Sammlung existiert nicht",
    "An error occurred" : "Es ist ein Fehler aufgetreten",
    "No picture for this day" : "Kein Bild für diesen Tag",
    "Picture taken on this day will show up here." : "Ein Bild, das an diesem Tag aufgenommen wurde, wird hier angezeigt.",
    "More photos from this day" : "Weitere Bilder von diesem Tag",
    "_%n unassigned photo_::_%n unassigned photos_" : ["%n nicht zugewiesenes Foto","%n nicht zugewiesene Fotos"],
    "Favorite" : "Favorisieren",
    "Select image {imageName}" : "Bild {imageName} auswählen",
    "Favorite image, open the full size \"{name}\" image" : "Favorisiertes Bild, öffne das Bild \"{name}\" in Originalgröße",
    "Open the full size \"{name}\" image" : "Bild \"{name}\" in Originalgröße öffnen",
    "Open the \"{name}\" folder" : "Ordner \"{name}\" öffnen",
    "Go back" : "Zurückgehen",
    "Back to {folder}" : "Zurück zu {folder}",
    "Share this folder" : "Diesen Ordner teilen",
    "Dates" : "Daten",
    "Jump to specific date in list" : "Zu einem bestimmten Datum in der Liste springen",
    "Jump to {date}" : "Zu {date} springen",
    "Add to {destination}" : "Hinzufügen zu {destination}",
    "The destination folder is owned by {owner}" : "Der Zielordner gehört {owner}",
    "There are no photos or videos yet!" : "Es gibt noch keine Fotos oder Videos!",
    "_{years} year ago_::_{years} years ago_" : ["Vor {years} Jahr","Vor {years} Jahren"],
    "Enable squared photos view" : "Quadratische Fotoansicht aktivieren",
    "Delete source directory" : "Quellverzeichnis löschen",
    "All folders" : "Alle Ordner",
    "Add a Photos source for the timelines" : "In Fotos eine Quelle für die Zeitleisten hinzufügen",
    "Add folder" : "Ordner hinzufügen",
    "Pick folder" : "Ordner auswählen",
    "Select a source folder for your media" : "Quellordner für Ihre Medien wählen",
    "Home" : "Startseite",
    "Choose default Photos upload and Albums location" : "Den Standardspeicherort für das Hochladen von Fotos und Alben wählen",
    "Choose a different folder" : "Anderen Ordner wählen",
    "Select the default upload location for your media" : "Standardspeicherort für Ihre hochgeladenen Medien auswählen",
    "View" : "Ansicht",
    "Media folders" : "Medienordner",
    "Choose the folders from where photos and videos are shown." : "Ordner wählen, aus dem Fotos und Videos angezeigt werden.",
    "Upload folder" : "Hochladen-Ordner",
    "Choose the folder where photos and albums are uploaded to." : "Ordner wählen, in den Fotos und Videos hochgeladen werden.",
    "_%n photo_::_%n photos_" : ["%n Foto","%n Fotos"],
    "Unselect all" : "Auswahl aufheben",
    "Add photos to this album" : "Fotos zu diesem Album hinzufügen",
    "Manage collaborators for this album" : "Mitbearbeitende für dieses Album verwalten",
    "Open actions menu" : "Aktionsmenü öffnen",
    "Edit album details" : "Albumdetails bearbeiten",
    "Download all files in album" : "Alle Dateien im Album herunterladen",
    "Delete album" : "Album löschen",
    "Download selected files" : "Ausgewählte Dateien herunterladen",
    "Remove selection from album" : "Auswahl aus Album entfernen",
    "This album does not have any photos or videos yet!" : "Dieses Album enthält noch keine Fotos oder Videos!",
    "Add photos to {albumName}" : "Fotos hinzufügen zu {albumName}",
    "Manage collaborators" : "Mitarbeitende verwalten",
    "Save collaborators for this album." : "Mitbearbeitende für dieses Album speichern.",
    "Cover photo for album {albumName}" : "Titelbild für Album {albumName}",
    "There is no album yet!" : "Es gibt noch kein Album!",
    "This person could not be found" : "Diese Person konnte nicht gefunden werden",
    "Rename person" : "Person umbenennen",
    "Merge with different person" : "Mit einer anderen Person zusammenführen",
    "Download selected photos" : "Ausgewählte Fotos herunterladen",
    "Remove from favorites" : "Von Favoriten entfernen",
    "Remove person" : "Person entfernen",
    "Name of this person" : "Name dieser Person",
    "Save." : "Speichern.",
    "Merge person" : "Person zusammenführen",
    "Move to different person" : "Zu einer anderen Person umziehen",
    "_Move photo to a different person_::_Move photos to a different person_" : ["Foto an eine andere Person verschieben","Fotos an eine andere Person verschieben"],
    "_Remove photo from person_::_Remove photos from person_" : ["Foto von Person entfernen","Fotos von Person entfernen"],
    "This might take some time depending on the size of your photo library." : "Dies kann je nach Größe Ihrer Fotobibliothek einige Zeit dauern.",
    "Recognized people will show up here" : "Erkannte Menschen werden hier angezeigt werden",
    "This folder does not exist" : "Dieser Ordner existiert nicht",
    "Loading folders …" : "Ordner werden geladen …",
    "No photos in here" : "Keine Fotos vorhanden",
    "Taken on {date} at {time}" : "Aufgenommen am {date} um {time}",
    "This place does not have any photos or videos yet!" : "Dieser Ort enthält noch keine Fotos oder Videos!",
    "Add photos to this place" : "Fotos zu diesem Ort hinzufügen",
    "Cover photo for place {placeName}" : "Titelbild für Ort {placeName}",
    "There is no place yet!" : "Es gibt noch keinen Ort",
    "Cover photo for shared album {albumName}." : "Titelbild für das geteilte Album {albumName}.",
    "Back to tags overview" : "Zurück zur Schlagwortübersicht",
    "No photos with this tag yet" : "Noch keine Fotos mit diesem Schlagwort",
    "No tags yet" : "Noch keine Schlagworte vorhanden",
    "Photos with tags will show up here" : "Fotos mit Schlagworten werden hier angezeigt",
    "Popular tags" : "Beliebte Schlagworte",
    "All tags" : "Alle Schlagworte",
    "One of the source folders does not exist" : "Einer der Quellordner existiert nicht",
    "Add to album" : "Zum Album hinzufügen",
    "Delete selection" : "Auswahl löschen",
    "No photos or videos in here" : "Hier gibt es keine Fotos oder Videos",
    "Unassigned faces" : "Nicht zugewiesene Gesichter",
    "_%n photos_::_%n photos_" : ["%n Foto","%n Fotos"],
    "Failed to fetch collection." : "Sammlung konnte nicht abgerufen werden.",
    "Failed to fetch collections list." : "Sammlungsliste konnte nicht geladen werden.",
    "Failed to fetch faces list." : "Gesichter-Liste konnte nicht geladen werden.",
    "All your media" : "Alle Ihre Medien",
    "Album {title}" : "Album {title}",
    "Shared Albums" : "Geteilte Alben",
    "Shared album {title}" : "Geteiltes Album {title}",
    "Public album {title}" : "Öffentliches Album {title}",
    "Tagged photos" : "Fotos mit Schlagworten",
    "Tagged photo {title}" : "Fotos mit Schlagworten",
    "{title}'s face" : "{title}s Gesicht",
    "{startDate} to {endDate}" : "{startDate} bis {endDate}",
    "Details" : "Details",
    "Failed to rename {oldName} to {faceName}." : "{oldName} konnte nicht in {faceName} umbenannt werden.",
    "Failed to delete {faceName}." : "{faceName} konnte nicht gelöscht werden.",
    "Failed to delete {fileId}." : "{fileId} konnte nicht gelöscht werden.",
    "Failed to delete {fileName}." : "{fileName} konnte nicht gelöscht werden.",
    "Failed to set favorite state for {fileId}." : "Fehler beim Festlegen des Favoritenstatus für {fileId}.",
    "Failed to set favorite state for {fileName}." : "Fehler beim Festlegen des Favoritenstatus für {fileName}.",
    "Could not load photos folder" : "Fotos-Ordner konnte nicht geladen werden",
    "One of the source folders does not exists" : "Einer der Quellordner existiert nicht",
    "Add" : "Hinzufügen"
},
"nplurals=2; plural=(n != 1);");
